from datetime import datetime


class Meal:

    def __init__(self, meal_time):
        self.now = datetime.now()
        self.meal_time = meal_time

    def is_time(self):
        for x in self.meal_time:
            if self.now.hour < x['start']:
                s = "现在还不是饭时，快吃" + x['zh'] + "了"
                return s
            if self.has_meal(x['start'], x['end']):
                s = "现在是吃" + x['zh'] + "的时候"
                return s
        return "别吃夜宵！实在忍不住吃点水果喝个牛奶"

    def has_meal(self, start, end):
        if (self.now.hour >= start) and (self.now.hour < end):
            return True
        return False









import toml
import os


def read_conf():
    path = os.path.dirname(__file__)
    with open(os.path.join(path, 'store.toml'), 'r') as f:
        toml_string = f.read()

    parsed_toml = toml.loads(toml_string)
    return parsed_toml



#!/usr/bin/env python3

import argparse
from lplib import choice, util, meal

# 以后要用到
ALL_OPT = {
    "vegetable": None,
    "movement": None,
    "fruit": None,
    "drink": None,
    "game": None
}


def cli_parser():
    parser = argparse.ArgumentParser(description="帮你做健康的选择")
    parser.add_argument("-v", "--vegetable", action="store_true", dest="vegetable", help="蔬菜")
    parser.add_argument("-m", "--movement", action="store_true", dest="movement", help="健身动作")
    parser.add_argument("-f", "--fruit", action="store_true", dest="fruit", help="水果")
    parser.add_argument("-d", "--drink", action="store_true", dest="drink", help="饮料")
    parser.add_argument("-g", "--game", action="store_true", dest="game", help="游戏")

    return parser


def cli():
    parser = cli_parser()
    args = parser.parse_args()
    conf = util.read_conf()

    lpl_choice = choice.Choice(conf['pool'], args)
    r = lpl_choice.choose_all()
    lpl_meal = meal.Meal(conf['meal_time'])

    print(lpl_meal.is_time())
    for x in r:
        print(x)


if "__main__" == __name__:
    cli()








from setuptools import setup, find_packages

setup(
    name="life-prolonging",
    version="0.0.2",
    keywords=["tool", "health"],
    license="MIT Licence",
    url="https://github.com/deadwind4/life-prolonging",
    author="deadwind",
    author_email="deadwind4@outlook.com",
    description="代码帮你选择",
    long_description="",
    install_requires=[
        'toml',
    ],
    packages=find_packages(where='.', exclude=(), include=('*',)),
    entry_points={
        "console_scripts": [
            'lpl = lpl:cli'
        ]
    },
    scripts=["lpl.py"],
    classifiers=(
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
    ),
)


from random import choice


class Choice:

    def __init__(self, pool, args):
        self.pool = pool
        self.args = args

    def choose_all(self):
        choices_results = []
        for category, v in self.args.__dict__.items():
            if v:
                r = self.choose(category)
                choices_results.append(r)
        return choices_results

    def choose(self, name):
        r = choice(self.pool[name])
        return r



